@@ -1,3 +1,5 @@
+import contextlib
+import logging
 import os
 import time
 import traceback
@@ -12,13 +14,36 @@ from timbermill.stack import Stack
 
 thread_instance = local()
 
+inited = False
+
 
 def init(timbermill_hostname: str, env: str = None, static_event_params=None, logger=None):
     timberlog_event_handler.init(timbermill_hostname, env, static_event_params, logger)
 
+    global inited
+    inited = True
+
 
 def start_task(name: str, retention_days: int = None):
-    return TimberLogContext(name, retention_days)
+    global inited
+
+    if not inited:
+        logging.getLogger(__name__).error('Trying to create a new timbermill task without it being inited, ignoring..')
+        return TimberLogNotInitedContext()
+    else:
+        return TimberLogContext(name, retention_days)
+
+
+class TimberLogNotInitedContext:
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        return False
+
+    def info(self, context=None, strings=None, metrics=None, text=None):
+        pass
 
 
 class TimberLogContext:
@@ -39,6 +64,9 @@ class TimberLogContext:
             end_with_error()
             return False
 
+    def info(self, context=None, strings=None, metrics=None, text=None):
+        info(context=context, strings=strings, metrics=metrics, text=text)
+
 
 def start(name: str, parent_id: str = None, retention_days: int = None) -> str:
     event, task_id, parent_id = __handle_new_task(name, consts.EVENT_TYPE_START, parent_id=parent_id, retention_days=retention_days)
@@ -63,7 +91,10 @@ def end_with_error(exception: BaseException = None):
 
 
 def spot(name: str, context: dict = None, strings: dict = None, metrics: dict = None, text: dict = None, parent_id: str = None, task_success: bool = True) -> str:
-    context, strings, metrics, text = timberlog_event_handler.init_dict_args([context, strings, metrics, text])
+    global inited
+    if not inited:
+        logging.getLogger(__name__).error('Trying to create a new timbermill spot event without it being inited, ignoring..')
+        return None
 
     if task_success:
         status = consts.SUCCESS_STATUS
